pub fn read_partition_table<'a, 'd>(
flash: &mut FlashStorage<'d>,
storage: &'a mut [u8],
) -> Result<PartitionTable<'a>, Error>Expand description
Read the partition table.
Pass FlashStorage and a buffer to read the partition table into.
pub fn read_partition_table<'a, 'd>(
flash: &mut FlashStorage<'d>,
storage: &'a mut [u8],
) -> Result<PartitionTable<'a>, Error>Read the partition table.
Pass FlashStorage and a buffer to read the partition table into.